=========
Changelog
=========

**Version 0.0.7**
===============

**Generate Django Code**
------------------------
- Models
    - Support abstract models and inheritance.
    - Support the use of slug field as lookup field.
    - Support the use of unique_together option
- Forms 
- Class Based Views
- Templates
- Tests
- Urls routing

**Generate Django Rest Framework Code**
---------------------------------------
- Serializers
    - Support writable nested serializers
- APIViews
- Routes

